@@ -27,12 +27,10 @@ public:
     Q_DECLARE_FLAGS(Options, Option)
 
     explicit PlayerSelector(PlayerSettings* playerSettings, Options options = DefaultBehavior, QWidget* parent = nullptr);
-    virtual ~PlayerSelector();
+    ~PlayerSelector() override;
 private:
     struct Private;
     Private* const d;
-
-    Q_PRIVATE_SLOT(d, void _k_showNewStuffDialog())
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(PlayerSelector::Options)
